import { Cache } from '../cache/cache.types';
declare type Method = 'GET' | 'HEAD' | 'POST' | 'PUT' | 'PATCH' | 'DELETE' | 'OPTIONS';
export declare type ResponseType = 'arrayBuffer' | 'blob' | 'json' | 'text' | 'formData';
export declare type ActionConfig = {
    emitErrorForStatuses?: number[];
};
export declare type Action<T = any> = {
    endpoint: string;
    method: Method;
    body?: any;
    headers?: {
        [propName: string]: string;
    };
    credentials?: RequestCredentials;
    cache?: RequestCache;
    mode?: RequestMode;
    referrerPolicy?: ReferrerPolicy;
    referrer?: string;
    integrity?: string;
    keepalive?: boolean;
    redirect?: RequestRedirect;
    signal?: AbortSignal | null;
    window?: any;
    config?: ActionConfig;
    responseType?: ResponseType;
} & T;
export declare type QueryResponse<T = any> = {
    status?: number;
    error: boolean;
    errorObject?: any;
    payload?: T;
    headers?: Headers;
};
export declare type UseQueryResponse<T> = {
    loading: boolean;
    abort: () => void;
    reset: () => void;
    query: () => Promise<QueryResponse<T>>;
} & QueryResponse<T>;
export declare type UseMutationResponse<S, T> = {
    abort: () => void;
    loading: boolean;
    mutate: (action: S) => Promise<QueryResponse<T>>;
    reset: () => void;
} & QueryResponse<T>;
export declare type Client<R = any> = {
    query: <T>(action: Action<R>, skipCache?: boolean) => Promise<QueryResponse<T>>;
    cache?: Cache<QueryResponse>;
};
export declare type ClientOptions<T> = {
    requestInterceptors?: Array<RequestInterceptor<T>>;
    responseInterceptors?: Array<ResponseInterceptor<T, any>>;
    cacheProvider?: Cache<QueryResponse>;
    fetch?: typeof fetch;
};
export declare type RequestInterceptor<T = any> = (client: Client<T>) => (action: Action<T>) => Promise<Action<T>>;
export declare type ResponseInterceptor<T = any, R = any> = (client: Client<T>) => (action: Action<T>, response: QueryResponse<R>) => Promise<QueryResponse<R>>;
export {};
